import { jsx, jsxs } from 'react/jsx-runtime';
import { useState, useMemo, useEffect } from 'react';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

function _typeof(obj) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
  }, _typeof(obj);
}

function requiredArgs(required, args) {
  if (args.length < required) {
    throw new TypeError(required + ' argument' + (required > 1 ? 's' : '') + ' required, but only ' + args.length + ' present');
  }
}

/**
 * @name toDate
 * @category Common Helpers
 * @summary Convert the given argument to an instance of Date.
 *
 * @description
 * Convert the given argument to an instance of Date.
 *
 * If the argument is an instance of Date, the function returns its clone.
 *
 * If the argument is a number, it is treated as a timestamp.
 *
 * If the argument is none of the above, the function returns Invalid Date.
 *
 * **Note**: *all* Date arguments passed to any *date-fns* function is processed by `toDate`.
 *
 * @param {Date|Number} argument - the value to convert
 * @returns {Date} the parsed date in the local time zone
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Clone the date:
 * const result = toDate(new Date(2014, 1, 11, 11, 30, 30))
 * //=> Tue Feb 11 2014 11:30:30
 *
 * @example
 * // Convert the timestamp to date:
 * const result = toDate(1392098430000)
 * //=> Tue Feb 11 2014 11:30:30
 */
function toDate(argument) {
  requiredArgs(1, arguments);
  var argStr = Object.prototype.toString.call(argument);

  // Clone the date
  if (argument instanceof Date || _typeof(argument) === 'object' && argStr === '[object Date]') {
    // Prevent the date to lose the milliseconds when passed to new Date() in IE10
    return new Date(argument.getTime());
  } else if (typeof argument === 'number' || argStr === '[object Number]') {
    return new Date(argument);
  } else {
    if ((typeof argument === 'string' || argStr === '[object String]') && typeof console !== 'undefined') {
      // eslint-disable-next-line no-console
      console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#string-arguments");
      // eslint-disable-next-line no-console
      console.warn(new Error().stack);
    }
    return new Date(NaN);
  }
}

/**
 * @name isWeekend
 * @category Weekday Helpers
 * @summary Does the given date fall on a weekend?
 *
 * @description
 * Does the given date fall on a weekend?
 *
 * @param {Date|Number} date - the date to check
 * @returns {Boolean} the date falls on a weekend
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Does 5 October 2014 fall on a weekend?
 * const result = isWeekend(new Date(2014, 9, 5))
 * //=> true
 */
function isWeekend(dirtyDate) {
  requiredArgs(1, arguments);
  var date = toDate(dirtyDate);
  var day = date.getDay();
  return day === 0 || day === 6;
}

/**
 * @name startOfDay
 * @category Day Helpers
 * @summary Return the start of a day for the given date.
 *
 * @description
 * Return the start of a day for the given date.
 * The result will be in the local timezone.
 *
 * @param {Date|Number} date - the original date
 * @returns {Date} the start of a day
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // The start of a day for 2 September 2014 11:55:00:
 * const result = startOfDay(new Date(2014, 8, 2, 11, 55, 0))
 * //=> Tue Sep 02 2014 00:00:00
 */
function startOfDay(dirtyDate) {
  requiredArgs(1, arguments);
  var date = toDate(dirtyDate);
  date.setHours(0, 0, 0, 0);
  return date;
}

/**
 * @name isSameDay
 * @category Day Helpers
 * @summary Are the given dates in the same day (and year and month)?
 *
 * @description
 * Are the given dates in the same day (and year and month)?
 *
 * @param {Date|Number} dateLeft - the first date to check
 * @param {Date|Number} dateRight - the second date to check
 * @returns {Boolean} the dates are in the same day (and year and month)
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Are 4 September 06:00:00 and 4 September 18:00:00 in the same day?
 * const result = isSameDay(new Date(2014, 8, 4, 6, 0), new Date(2014, 8, 4, 18, 0))
 * //=> true
 *
 * @example
 * // Are 4 September and 4 October in the same day?
 * const result = isSameDay(new Date(2014, 8, 4), new Date(2014, 9, 4))
 * //=> false
 *
 * @example
 * // Are 4 September, 2014 and 4 September, 2015 in the same day?
 * const result = isSameDay(new Date(2014, 8, 4), new Date(2015, 8, 4))
 * //=> false
 */
function isSameDay(dirtyDateLeft, dirtyDateRight) {
  requiredArgs(2, arguments);
  var dateLeftStartOfDay = startOfDay(dirtyDateLeft);
  var dateRightStartOfDay = startOfDay(dirtyDateRight);
  return dateLeftStartOfDay.getTime() === dateRightStartOfDay.getTime();
}

/**
 * @name getDay
 * @category Weekday Helpers
 * @summary Get the day of the week of the given date.
 *
 * @description
 * Get the day of the week of the given date.
 *
 * @param {Date|Number} date - the given date
 * @returns {0|1|2|3|4|5|6} the day of week, 0 represents Sunday
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Which day of the week is 29 February 2012?
 * const result = getDay(new Date(2012, 1, 29))
 * //=> 3
 */
function getDay(dirtyDate) {
  requiredArgs(1, arguments);
  var date = toDate(dirtyDate);
  var day = date.getDay();
  return day;
}

/**
 * @name getDaysInMonth
 * @category Month Helpers
 * @summary Get the number of days in a month of the given date.
 *
 * @description
 * Get the number of days in a month of the given date.
 *
 * @param {Date|Number} date - the given date
 * @returns {Number} the number of days in a month
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // How many days are in February 2000?
 * const result = getDaysInMonth(new Date(2000, 1))
 * //=> 29
 */
function getDaysInMonth(dirtyDate) {
  requiredArgs(1, arguments);
  var date = toDate(dirtyDate);
  var year = date.getFullYear();
  var monthIndex = date.getMonth();
  var lastDayOfMonth = new Date(0);
  lastDayOfMonth.setFullYear(year, monthIndex + 1, 0);
  lastDayOfMonth.setHours(0, 0, 0, 0);
  return lastDayOfMonth.getDate();
}

/**
 * @name getMonth
 * @category Month Helpers
 * @summary Get the month of the given date.
 *
 * @description
 * Get the month of the given date.
 *
 * @param {Date|Number} date - the given date
 * @returns {Number} the month
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Which month is 29 February 2012?
 * const result = getMonth(new Date(2012, 1, 29))
 * //=> 1
 */
function getMonth(dirtyDate) {
  requiredArgs(1, arguments);
  var date = toDate(dirtyDate);
  var month = date.getMonth();
  return month;
}

/**
 * @name getYear
 * @category Year Helpers
 * @summary Get the year of the given date.
 *
 * @description
 * Get the year of the given date.
 *
 * @param {Date|Number} date - the given date
 * @returns {Number} the year
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // Which year is 2 July 2014?
 * const result = getYear(new Date(2014, 6, 2))
 * //=> 2014
 */
function getYear(dirtyDate) {
  requiredArgs(1, arguments);
  return toDate(dirtyDate).getFullYear();
}

/**
 * @name isAfter
 * @category Common Helpers
 * @summary Is the first date after the second one?
 *
 * @description
 * Is the first date after the second one?
 *
 * @param {Date|Number} date - the date that should be after the other one to return true
 * @param {Date|Number} dateToCompare - the date to compare with
 * @returns {Boolean} the first date is after the second date
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Is 10 July 1989 after 11 February 1987?
 * const result = isAfter(new Date(1989, 6, 10), new Date(1987, 1, 11))
 * //=> true
 */
function isAfter(dirtyDate, dirtyDateToCompare) {
  requiredArgs(2, arguments);
  var date = toDate(dirtyDate);
  var dateToCompare = toDate(dirtyDateToCompare);
  return date.getTime() > dateToCompare.getTime();
}

/**
 * @name isBefore
 * @category Common Helpers
 * @summary Is the first date before the second one?
 *
 * @description
 * Is the first date before the second one?
 *
 * @param {Date|Number} date - the date that should be before the other one to return true
 * @param {Date|Number} dateToCompare - the date to compare with
 * @returns {Boolean} the first date is before the second date
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // Is 10 July 1989 before 11 February 1987?
 * const result = isBefore(new Date(1989, 6, 10), new Date(1987, 1, 11))
 * //=> false
 */
function isBefore(dirtyDate, dirtyDateToCompare) {
  requiredArgs(2, arguments);
  var date = toDate(dirtyDate);
  var dateToCompare = toDate(dirtyDateToCompare);
  return date.getTime() < dateToCompare.getTime();
}

/**
 * @name isToday
 * @category Day Helpers
 * @summary Is the given date today?
 * @pure false
 *
 * @description
 * Is the given date today?
 *
 * > ⚠️ Please note that this function is not present in the FP submodule as
 * > it uses `Date.now()` internally hence impure and can't be safely curried.
 *
 * @param {Date|Number} date - the date to check
 * @returns {Boolean} the date is today
 * @throws {TypeError} 1 argument required
 *
 * @example
 * // If today is 6 October 2014, is 6 October 14:00:00 today?
 * const result = isToday(new Date(2014, 9, 6, 14, 0))
 * //=> true
 */
function isToday(dirtyDate) {
  requiredArgs(1, arguments);
  return isSameDay(dirtyDate, Date.now());
}

function Day(props) {
    var month = props.month, year = props.year, day = props.day, _a = props.calendarEvents, calendarEvents = _a === void 0 ? [] : _a;
    var _b = useState(false), show = _b[0], setShow = _b[1];
    var isWeekEnd = useMemo(function () {
        return isWeekend(new Date(year, month, day));
    }, [month, year, day]);
    var today = useMemo(function () {
        return isToday(new Date(year, month, day));
    }, [month, year, day]);
    var eventsOfDay = calendarEvents.filter(function (ev) {
        return isSameDay(new Date(year, month, day), ev.from) || isSameDay(new Date(year, month, day), ev.to)
            || (isAfter(new Date(year, month, day), ev.from) && isBefore(new Date(year, month, day), ev.to));
    });
    var showEvents = function () {
        if (eventsOfDay.length) {
            setShow(true);
        }
    };
    var hideEvents = function () {
        setShow(false);
    };
    return (jsx("div", __assign({ onClick: showEvents, onBlur: hideEvents, tabIndex: 0, className: "day popup " }, { children: jsxs("div", __assign({ className: "day_container ".concat(isWeekEnd ? "week-end" : '', " ").concat(today ? "today" : "", " ").concat(eventsOfDay.length ? "events-found" : "") }, { children: [day, show && jsx("div", __assign({ className: "popuptext show" }, { children: eventsOfDay.map(function (d, i) {
                        return jsxs("div", __assign({ className: "popup_text_item" }, { children: [jsx("span", __assign({ className: "event_title" }, { children: d.title })), " - ", d.from.getHours() + ":" + d.from.getMinutes(), " - ", d.to.getHours() + ":" + d.to.getMinutes()] }), "event-".concat(i));
                    }) }))] })) })));
}

var weeks$1 = [
	"Sun",
	"Mon",
	"Tue",
	"Wed",
	"Thu",
	"Fri",
	"Sat"
];
var months$1 = [
	"January",
	"February",
	"March",
	"April",
	"May",
	"June",
	"July",
	"August",
	"September",
	"October",
	"November",
	"December"
];
var translation = {
	weeks: weeks$1,
	months: months$1
};

var weeks = [0, 1, 2, 3, 4, 5, 6];
function Month(props) {
    var month = props.month, year = props.year, calendarEvents = props.calendarEvents;
    var firstDayOfWeek = getDay(new Date(year, month, 1));
    var getWeekDay = function (day) {
        if (firstDayOfWeek <= day && getDaysInMonth(new Date(year, month)) >= (day - firstDayOfWeek + 1)) {
            return jsx(Day, { month: month, year: year, day: day - firstDayOfWeek + 1, calendarEvents: calendarEvents }, "".concat(year, " ").concat(month, " ").concat(day));
        }
        return jsx("div", { className: 'day' }, "".concat(year, " ").concat(month, " ").concat(day));
    };
    return (jsxs("div", { children: [weeks.map(function (week, index) {
                return jsx("div", __assign({ className: "week-head ".concat(index === 0 || index === weeks.length - 1 ? "week-end" : "") }, { children: translation.weeks[week] }), index);
            }), jsx("div", {}), Array.from(Array(42).keys()).map(function (day) {
                return getWeekDay(day);
            })] }));
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "*, ::after, ::before {\n  box-sizing: border-box;\n}\n\n.react-calendar-events {\n  text-align: center;\n  /* Popup container */\n  /* The actual popup (appears on top) */\n  /* Popup arrow */\n  /* Toggle this class when clicking on the popup container (hide and show the popup) */\n  /* Add animation (fade in the popup) */\n}\n.react-calendar-events .day {\n  display: inline-block;\n  vertical-align: top;\n  width: 14.2857143%;\n  margin-bottom: 5px;\n  min-width: 41px;\n  min-height: 18px;\n  padding: 0px 1px;\n}\n.react-calendar-events .week-head {\n  display: inline-block;\n  vertical-align: top;\n  width: 14.2857143%;\n  margin-bottom: 5px;\n  padding: 0px 1px;\n}\n.react-calendar-events .month {\n  padding: 5px;\n  border: 1px solid rgb(58, 58, 58);\n  display: inline-block;\n  vertical-align: top;\n  margin: 1px;\n  flex: 1 1 306px;\n}\n.react-calendar-events .year-view {\n  width: 100%;\n  height: 100%;\n  display: flex;\n  flex-wrap: wrap;\n}\n.react-calendar-events .month-view {\n  padding: 5px;\n  border: 1px solid rgb(58, 58, 58);\n  width: 100%;\n  height: 100%;\n  max-width: 537px;\n}\n.react-calendar-events .year-head {\n  margin: 5px;\n  padding: 5px;\n}\n.react-calendar-events .month-head {\n  margin: 5px;\n}\n.react-calendar-events .week-end {\n  color: gray;\n}\n.react-calendar-events .today {\n  color: red;\n  font-weight: bold;\n}\n.react-calendar-events .events-found {\n  font-weight: bold;\n  border: 1px solid #3b91ad;\n  border-radius: 5000px;\n  position: relative;\n}\n.react-calendar-events .events-found::before {\n  content: \"\";\n  width: 4px;\n  height: 4px;\n  border-radius: 50%;\n  background-color: red;\n  position: absolute;\n  top: 2px;\n  right: 5px;\n}\n.react-calendar-events .popup {\n  position: relative;\n  display: inline-block;\n  cursor: pointer;\n}\n.react-calendar-events .popup .popuptext {\n  visibility: hidden;\n  background-color: #3b91ad;\n  color: #ffffff;\n  text-align: center;\n  border-radius: 6px;\n  padding: 8px;\n  position: absolute;\n  z-index: 1;\n  bottom: calc(100% + 8px);\n  left: -81px;\n  border: 1px solid #3b91ad;\n}\n.react-calendar-events .popup .popuptext .popup_text_item {\n  padding: 5px 0px;\n  width: 100%;\n  max-width: 500px;\n  width: max-content;\n}\n.react-calendar-events .popup .popuptext .popup_text_item .event_title {\n  position: relative;\n}\n.react-calendar-events .popup .popuptext .popup_text_item .event_title::before {\n  content: \"\";\n  height: 1px;\n  background-color: #ffffff;\n  width: 100%;\n  position: absolute;\n  bottom: -2px;\n  left: 0px;\n}\n.react-calendar-events .popup .popuptext::after {\n  content: \"\";\n  position: absolute;\n  top: 100%;\n  left: 100px;\n  margin-left: -5px;\n  border-width: 5px;\n  border-style: solid;\n  border-color: #3b91ad transparent transparent transparent;\n}\n.react-calendar-events .popup .show {\n  visibility: visible;\n  -webkit-animation: fadeIn 1s;\n  animation: fadeIn 1s;\n}\n@-webkit-keyframes fadeIn {\n  from {\n    opacity: 0;\n  }\n  to {\n    opacity: 1;\n  }\n}\n@keyframes fadeIn {\n  from {\n    opacity: 0;\n  }\n  to {\n    opacity: 1;\n  }\n}\n.react-calendar-events .react_calendar_flex_box {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n}\n.react-calendar-events .react_calendar_margin {\n  margin-right: 0.5rem;\n}\n.react-calendar-events .react_calendar_top_toggle_bar {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  font-size: 14px;\n  padding: 10px 0px;\n}\n.react-calendar-events .react_calendar_top_toggle_bar .react_calendar_top_toggle_container {\n  margin-right: 10px;\n}\n.react-calendar-events .react_calendar_top_toggle_bar .react_calendar_round_toggle {\n  background-color: #3b91ad;\n  color: #ffffff;\n  padding: 5px 20px;\n  border-radius: 5000px;\n  cursor: pointer;\n}";
styleInject(css_248z);

var months = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
var getValidMonth = function (month) {
    if ((month || month === 0) && month < 11 && month > 0) {
        return month;
    }
    return getMonth(new Date());
};
function Calendar(props) {
    var _a = useState({
        month: getValidMonth(props.defaultMonth),
        year: props.defaultYear ? props.defaultYear : getYear(new Date())
    }), state = _a[0], setState = _a[1];
    var _b = useState(props.monthView ? true : false), monthView = _b[0], setMonthView = _b[1];
    useEffect(function () {
        setMonthView(props.monthView ? true : false);
    }, [props.monthView]);
    var changeYear = function (val) {
        setState(__assign(__assign({}, state), { year: state.year + val }));
    };
    var changeMonth = function (val) {
        var temp = __assign({}, state);
        temp.month = temp.month + val;
        if (temp.month > 11) {
            temp.month = 0;
            temp.year += 1;
        }
        else if (temp.month < 0) {
            temp.month = 11;
            temp.year -= 1;
        }
        setState(temp);
    };
    return (jsxs("div", __assign({ className: "react-calendar-events" }, { children: [jsxs("div", __assign({ className: 'react_calendar_top_toggle_bar' }, { children: [jsx("div", __assign({ className: 'react_calendar_top_toggle_container' }, { children: monthView ?
                            jsxs("div", __assign({ className: 'react_calendar_flex_box' }, { children: [jsxs("div", __assign({ className: 'react_calendar_flex_box react_calendar_margin' }, { children: [jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin', onClick: function () { return changeYear(-1); } }, { children: "-" })), jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin' }, { children: state.year })), jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin', onClick: function () { return changeYear(1); } }, { children: "+" }))] })), jsxs("div", __assign({ className: 'react_calendar_flex_box' }, { children: [jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin', onClick: function () { return changeMonth(-1); } }, { children: "-" })), jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin' }, { children: translation.months[state.month] })), jsx("div", __assign({ className: 'react_calendar_round_toggle', onClick: function () { return changeMonth(1); } }, { children: "+" }))] }))] }))
                            :
                                jsxs("div", __assign({ className: 'react_calendar_flex_box' }, { children: [jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin', onClick: function () { return changeYear(-1); } }, { children: "-" })), jsx("div", __assign({ className: 'react_calendar_round_toggle react_calendar_margin' }, { children: state.year })), jsx("div", __assign({ className: 'react_calendar_round_toggle', onClick: function () { return changeYear(1); } }, { children: "+" }))] })) })), jsx("div", __assign({ className: 'react_calendar_top_toggle_view_switch_container' }, { children: jsx("div", __assign({ onClick: function () { return setMonthView(!monthView); }, className: "react_calendar_round_toggle" }, { children: monthView ? "Year View" : "Month View" })) }))] })), monthView ?
                jsx("div", __assign({ className: 'react_calendar_flex_box' }, { children: jsx("div", __assign({ className: "month-view" }, { children: jsx(Month, __assign({}, state, { calendarEvents: props.calendarEvents })) })) }))
                :
                    jsx("div", { children: jsx("div", __assign({ className: 'year-view' }, { children: months.map(function (month) {
                                return jsxs("div", __assign({ className: "month" }, { children: [jsx("div", __assign({ className: 'month-head' }, { children: translation.months[month] })), jsx(Month, { year: state.year, month: month, calendarEvents: props.calendarEvents })] }), month);
                            }) })) })] })));
}

export { Calendar as default };
//# sourceMappingURL=index.js.map
